==> haskell-megaparsec-9.7.0-50.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
key:                  megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  0a7abf13e908f06a80a3f3bb6aa6918a
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    deepseq-1.4.8.1 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-9.7.0-51-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
key:                  megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  ad0730716e9eb5e300718f5f3356bcb8
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    deepseq-1.4.8.1 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
